@@ -26,7 +26,7 @@ from shake import url_for, Render
 __all__ = (
     'split_hash', 'generate_salt', 'pbkdf2',
     'hash_sha256', 'hash_sha512', 'hash_bcrypt', 'hash_scrypt',
-    'get_user_model', 'LazyUser', 'Token',
+    'get_user_model', 'LazyUser', 'Token', 'auth_render',
 )
 
 
